@@ -16,7 +16,8 @@ use guppy::{
         feature::{FeatureFilter, FeatureSet, StandardFeatures},
         DependencyDirection, PackageGraph, PackageMetadata, PackageSet, Workspace,
     },
-    PackageId, Platform,
+    platform::PlatformSpec,
+    PackageId,
 };
 use itertools::Itertools;
 use petgraph::{graphmap::GraphMap, Directed};
@@ -61,8 +62,8 @@ impl<'g, 'a> Determinator<'g, 'a> {
     /// Adds a list of changed paths. This list is used as a source of information for the
     /// determinator.
     ///
-    /// This should consist of paths that are changed since the base revision, and should use the
-    /// canonical separator for the platform (e.g. `/` on Unix platforms and `\` on Windows).
+    /// This should consist of paths that are changed since the base revision. Paths on Windows may
+    /// use either `/` or `\\` as separators.
     ///
     /// [`Utf8Paths0`](crate::Utf8Paths0) in this crate provides a convenient way to handle
     /// null-separated paths as produced by source control systems.
@@ -149,9 +150,9 @@ impl<'g, 'a> Determinator<'g, 'a> {
     /// * the host and target platforms are set to the current platform
     pub fn default_cargo_options() -> CargoOptions<'static> {
         let mut options = CargoOptions::new();
-        options.set_include_dev(true).set_platform(Some(
-            Platform::current().expect("current platform is unknown"),
-        ));
+        options
+            .set_include_dev(true)
+            .set_platform(PlatformSpec::current().expect("current platform is unknown"));
         options
     }
 
